Learn R Programming

SDR (version 0.7.0.0)

addKeelRegister: Add one or a set of instances to a KEEL dataset.

Description

Take a data vector or a list of data vectors and inserts at the end of a keel data set.

Usage

addKeelRegister(items, dataset)

Arguments

items
Vector or list of instance/s
dataset
The keel dataset to insert the data.

Value

Returns the new dataset with data introduced. This dataset is a list with a vectors of every instace. This dataset should be stored into the $data field of a keel class variable.

Details

You can add the data in four ways:
  • A single element, using a vector.
    • Coded.
    • Uncoded.

  • More than one element, using a list of vectors.
    • Coded.
    • Uncoded.

Coded means that vectors of data are all numeric (including class) and, obviously, all values are within the bounds stablished. This way is the returned after a read.keel() call and it is the ideal for introduce data from one dataset to another, for example.

Uncoded means that vectors of data are characters, because it has at least one value that is a string (class value) and values are valid. This is common when we read a csv file or we introduce data manually, for example.

References

J. Alcala-Fdez, A. Fernandez, J. Luengo, J. Derrac, S. Garcia, L. Sanchez, F. Herrera. KEEL Data-Mining Software Tool: Data Set Repository, Integration of Algorithms and Experimental Analysis Framework. Journal of Multiple-Valued Logic and Soft Computing 17:2-3 (2011) 255-287.

See Also

KEEL Dataset Repository (Standard Classification): http://sci2s.ugr.es/keel/category.php?cat=clas