keel data set.
addKeelRegister(items, dataset)keel dataset to insert the data.$data
field of a keel class variable.
Coded means that vectors of data are all numeric (including class) and, obviously,
all values are within the bounds stablished. This way is the returned after a read.keel() call
and it is the ideal for introduce data from one dataset to another, for example.
Uncoded means that vectors of data are characters, because it has at least one value that is a string (class value) and values are valid. This is common when we read a csv file or we introduce data manually, for example.